/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef CONEXUSMMADDRESSENTRY_H
#define CONEXUSMMADDRESSENTRY_H

#include <set>
#include <conexus.h>


namespace ConexusGtk {

/**
	@author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
*/
class AddressContainer{
public:

  typedef std::set<Conexus::IPv4::Address*> IPv4Addresses;
  typedef std::set<Conexus::IPv4::Address*>::iterator IPv4Iterator;
  typedef std::set<Conexus::IPv6::Address*> IPv6Addresses;
  typedef std::set<Conexus::IPv6::Address*>::iterator IPv6Iterator;
  typedef enum ValidateType { IPV4=1, IPV6=2 } ValidateType;

    AddressContainer(unsigned validate=IPV4|IPV6);

    virtual ~AddressContainer();

    void connect(Conexus::IPv4::Address& address);
    void disconnect(Conexus::IPv4::Address& address);
    void connect(Conexus::IPv6::Address& address);
    void disconnect(Conexus::IPv6::Address& address);

    unsigned validate_type();
    void set_validate_type(unsigned validate);

  protected:
    unsigned m_validate_type;
    IPv4Addresses m_ipv4_address;
    IPv6Addresses m_ipv6_address;

    virtual void on_connect(Conexus::IPv4::Address& address);
    virtual void on_disconnect(Conexus::IPv4::Address& address);
    virtual void on_connect(Conexus::IPv6::Address& address);
    virtual void on_disconnect(Conexus::IPv6::Address& address);
    virtual void on_validate_type_changed();

};

}

#endif
