/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#include "endpointstopbutton.h"
namespace ConexusGtk
{

  EndpointStopButton::EndpointStopButton( bool show_text, bool show_image ):
      m_start_image( &m_default_start_image ),
      m_default_start_image( Gtk::Stock::CONNECT, Gtk::IconSize( Gtk::ICON_SIZE_LARGE_TOOLBAR ) ),
      m_stop_image( &m_default_stop_image ),
      m_default_stop_image( Gtk::Stock::DISCONNECT, Gtk::IconSize( Gtk::ICON_SIZE_LARGE_TOOLBAR ) )
  {
    m_text.set_use_markup();

    this->set_start_text_to_default();
    this->set_stop_text_to_default();
    
    m_default_start_image.show();
    m_default_stop_image.show();
    
    if ( show_text )
      this->show_text( );
    else
      this->hide_text( );
    
    if ( show_image )
      this->show_image( );
    else
      this->hide_image( );
    
    m_hbox.set_spacing( 5 );
    m_hbox.pack_start( m_imagebox, Gtk::PACK_SHRINK );
    m_hbox.pack_start( m_text, Gtk::PACK_SHRINK );
    m_hbox.show();
    set_image( m_hbox );
    
    this->update_display( );
    
    this->signal_toggled().connect( sigc::mem_fun( *this, &EndpointStopButton::on_button_toggled ) );
  }


  EndpointStopButton::~EndpointStopButton()
  {}

  void EndpointStopButton::connect( Conexus::Endpoint & io )
  {
    bool active =  this->get_active();
    m_controlled.insert( &io );
    if ( this->get_active() )
      io.start();
    else
      io.stop();
  }

  void EndpointStopButton::disconnect( Conexus::Endpoint & io )
  {
    m_controlled.erase( &io );
  }

  const Glib::ustring & EndpointStopButton::start_text( )
  {
    return m_start_text;
  }

  const Glib::ustring & EndpointStopButton::stop_text( )
  {
    return m_stop_text;
  }

  void EndpointStopButton::set_start_text( const Glib::ustring & text )
  {
    m_start_text = text;
    this->update_display();
  }

  void EndpointStopButton::set_start_text_to_default( )
  {
    this->set_start_text( "Connected  <i><small>( Click to Disconnect )</small></i>" );
  }

  void EndpointStopButton::set_stop_text( const Glib::ustring & text )
  {
    m_stop_text = text;
    this->update_display();
  }

  void EndpointStopButton::set_stop_text_to_default( )
  {
    this->set_stop_text( "Disconnected  <i><small>( Click to Connect )</small></i>" );
  }

  bool EndpointStopButton::is_text_visible( )
  {
    return m_text.is_visible();
  }

  void EndpointStopButton::show_text( )
  {
    m_text.show();
  }

  void EndpointStopButton::hide_text( )
  {
    m_text.hide();
  }

  const Gtk::Image & EndpointStopButton::start_image( )
  {
    return *m_start_image;
  }

  const Gtk::Image & EndpointStopButton::stop_image( )
  {
    return *m_stop_image;
  }

  void EndpointStopButton::set_start_image( Gtk::Image & image )
  {
    m_start_image = &image;
    this->update_display();
  }

  void EndpointStopButton::set_start_image_to_default( )
  {
    m_start_image = &m_default_start_image;
    this->update_display();
  }

  void EndpointStopButton::set_stop_image( Gtk::Image & image )
  {
    m_stop_image = &image;
    this->update_display();
  }

  void EndpointStopButton::set_stop_image_to_default( )
  {
    m_stop_image = &m_default_stop_image;
    this->update_display();
  }

  bool EndpointStopButton::is_image_visible( )
  {
    return m_imagebox.is_visible();
  }

  void EndpointStopButton::show_image( )
  {
    m_imagebox.show_all();
  }

  void EndpointStopButton::hide_image( )
  {
    m_imagebox.hide();
  }

  void EndpointStopButton::on_button_toggled( )
  {
    bool active = this->get_active();
    update_display( );
    Controlled::iterator i;
    for ( i = m_controlled.begin(); i != m_controlled.end(); i++ )
    {
      if ( active )
        (*i)->start();
      else
        (*i)->stop();
    }
  }

  void EndpointStopButton::update_display( )
  {
    if ( this->get_active() ) {
      if ( m_imagebox.get_child() != NULL )
        m_imagebox.remove();
      m_imagebox.add( *m_start_image );
      m_text.set_markup( m_start_text );
    } else {
      if ( m_imagebox.get_child() != NULL )
        m_imagebox.remove();
      m_imagebox.add( *m_stop_image );
      m_text.set_markup( m_stop_text );
    }
  }

}


