/***************************************************************************
 *   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef CONEXUSMMPORTENTRY_H
#define CONEXUSMMPORTENTRY_H

#include <gtkmm.h>
#include <conexus.h>

#include <conexusmm/addresscontainer.h>

namespace ConexusGtk {

/**
 * TODO need to add TCP/UDP service lookup for those that do differ
 * @author Rick L Vinyard Jr
 */
class PortEntry : public AddressContainer, public Gtk::VBox
{
public:
  PortEntry(unsigned validate = IPV4|IPV6);
  PortEntry(Conexus::IPv4::Address& addr, unsigned validate = IPV4);
  PortEntry(Conexus::IPv6::Address& addr, unsigned validate = IPV6);

    ~PortEntry();

    Gtk::SpinButton& get_port_button();
    Gtk::Adjustment& get_port_adjustment();

    uint32_t get_port();
    void set_port(uint32_t p);

    sigc::signal<void> signal_port_changed();

    bool get_show_servicename_label();
    
    void set_show_servicename_label(bool show=true);

  protected:
    sigc::signal<void> m_signal_port_changed;

    Gtk::SpinButton m_port;
    Gtk::Adjustment m_port_adjustment;
    Gtk::Label m_servicename_label;

    virtual void on_port_changed();

    void on_spinbutton_text_entry( const Glib::ustring & text, int * position );
    void on_spinbutton_text_delete(int start, int end);

    virtual void on_connect(Conexus::IPv4::Address& address);
    virtual void on_connect(Conexus::IPv6::Address& address);
    
    virtual void on_validate_type_changed();

  private:
    void setup_widget();

};

}

#endif
