/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#include "spinner.h"

#include "logo.h"

#include <papyrus/rectangle.h>

#include <cmath>

namespace ConexusGtk {

Spinner::Spinner(unsigned spin_units)
 : PapyrusGtk::Viewport(),
 m_spin_units(spin_units),
 m_data_count(0)
{
  double default_side = 50.0;
  double side = sqrt( 2.0 * (default_side-4.0) * (default_side-4.0) )/2.0;
  Papyrus::Image::pointer logo = Logo::create();
  logo->set_viewbox( Papyrus::Viewbox::create(-side/2.0, -side/2.0, side, side) );
  this->canvas()->add( logo );
  
  Papyrus::Rectangle::pointer rect = Papyrus::Rectangle::create();
  rect->set_xywh( -default_side/2.0, -default_side/2.0, default_side, default_side );
  rect->set_outline( Cairo::SolidPattern::create_rgb(0.0, 0.0, 0.0) );
  this->canvas()->add( rect );
      
  this->set_size_request( (int)default_side, (int)default_side );
  m_animator.set_rotate( M_PI / 45.0 );
  m_animator.add( logo );
}


Spinner::~Spinner()
{
}

unsigned Spinner::spin_units( )
{
  return m_spin_units;
}

void Spinner::set_spin_units( unsigned units )
{
  m_spin_units = units;
}

void Spinner::on_data( size_t n )
{
  if ( m_spin_units == 0 )
  {
    m_animator.advance();
  }
  else 
  {
    m_data_count += n;
      
  if ( m_data_count > m_spin_units ) {
    m_animator.advance( m_data_count / m_spin_units );
    m_data_count %= m_spin_units;
  } 
  }
}

void Spinner::on_read_data( size_t n )
{
  this->on_data( n );
}

void Spinner::on_write_data( size_t n )
{
  this->on_data( n );
}


}

