/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#include "ttystopbitsradio.h"

#include <sstream>

#include <gtkmm/separator.h>

namespace ConexusGtk {

TTYStopBitsRadio::TTYStopBitsRadio(unsigned stop_bits)
{
  Gtk::RadioButtonGroup group;
  m_stop_bits = stop_bits;
  
  m_radio_button[0].set_label("1");
  m_radio_button[1].set_label("2");
  
  this->attach(m_radio_button[ 0 ], 0, 1, 0, 1 );
  this->attach( *Gtk::manage( new Gtk::VSeparator() ), 1, 2, 0, 1 );
  this->attach(m_radio_button[ 1 ], 2, 3, 0, 1 );
  
  m_radio_button[0].set_group(group);
  m_radio_button[1].set_group(group);
  
  m_radio_button[0].signal_toggled().connect( sigc::bind( sigc::mem_fun( *this, &TTYStopBitsRadio::on_button_changed ), 1 ) );
  m_radio_button[1].signal_toggled().connect( sigc::bind( sigc::mem_fun( *this, &TTYStopBitsRadio::on_button_changed ), 2 ) );

  this->set_stop_bits( stop_bits );
}


TTYStopBitsRadio::~TTYStopBitsRadio()
{
}

unsigned TTYStopBitsRadio::stop_bits( )
{
  return m_stop_bits;
}

void TTYStopBitsRadio::set_stop_bits( unsigned stop_bits )
{
  if ( stop_bits < 1 || stop_bits > 2 )
    stop_bits = 1;
  m_radio_button[ stop_bits-1 ].set_active(true);
}

sigc::signal< void > TTYStopBitsRadio::signal_changed( )
{
  return m_signal_changed;
}

void TTYStopBitsRadio::on_button_changed( unsigned stop_bits )
{
  m_stop_bits = stop_bits;
  m_signal_changed.emit();
}

}

