/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef CONEXUSMMTTYWIDGET_H
#define CONEXUSMMTTYWIDGET_H

#include <gtkmm/table.h>

#include <conexusmm/serialcombobox.h>
#include <conexusmm/ttybytesizeradio.h>
#include <conexusmm/ttyflowcontrolcombobox.h>
#include <conexusmm/ttyparitycombobox.h>
#include <conexusmm/ttyparityerrorcombobox.h>
#include <conexusmm/ttyspeedcombobox.h>
#include <conexusmm/ttystopbitsradio.h>

namespace ConexusGtk {

/**
	@author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
*/
class TTYWidget : public Gtk::Table
{
public:
    TTYWidget();

    ~TTYWidget();

    void connect( Conexus::TTY& tty );
    void disconnect( );
    
    SerialComboBox& device_widget();
    TTYStopBitsRadio& stop_bits_widget();
    TTYByteSizeRadio& byte_size_widget();
    TTYFlowControlComboBox& flow_control_widget();
    TTYParityComboBox& parity_widget();
    TTYParityErrorComboBox& parity_error_widget();
    TTYSpeedComboBox& input_speed_widget();
    TTYSpeedComboBox& output_speed_widget();
    Gtk::CheckButton& carrier_detect_widget();
    Gtk::CheckButton& receiver_enable_button();
    
  protected:
    Conexus::TTY* m_tty;
    
    SerialComboBox m_serial_combobox;
    TTYStopBitsRadio m_stop_bits_radio;
    TTYByteSizeRadio m_byte_size_radio;
    TTYFlowControlComboBox m_flow_control_combobox;
    TTYParityComboBox m_parity_combobox;
    TTYParityErrorComboBox m_parity_error_combobox;
    TTYSpeedComboBox m_input_speed_combobox, m_output_speed_combobox;
    Gtk::Button m_link_speed_button;
    bool m_speed_linked;
    Glib::RefPtr<Gdk::Pixbuf> m_link_image, m_unlink_image;
    Gtk::CheckButton m_carrier_detect;
    Gtk::CheckButton m_receiver_enable_button;

    void on_serial_device_changed();
    void on_byte_size_changed();
    void on_stop_bits_changed();
    void on_flow_control_changed();
    void on_parity_changed();
    void on_parity_error_changed();
    void on_input_speed_changed();
    void on_output_speed_changed();
    void on_speed_link_changed();
    void on_carrier_detect_changed();
    void on_receiver_enable_changed();
};

}

#endif
